==> jc-1.4.0.tar.gz: javax/swing/text/TextAction.h <==
// public abstract class javax.swing.text.TextAction

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_text_TextAction_H_
#define _JC_javax_swing_text_TextAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_JTextComponent$object;

// Typedefs
typedef struct _jc_javax_swing_text_TextAction$sub_refs	_jc_javax_swing_text_TextAction$sub_refs;
typedef struct _jc_javax_swing_text_TextAction$sub_nonrefs	_jc_javax_swing_text_TextAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_TextAction$refs	_jc_javax_swing_text_TextAction$refs;
typedef struct _jc_javax_swing_text_TextAction$nonrefs	_jc_javax_swing_text_TextAction$nonrefs;
typedef struct _jc_javax_swing_text_TextAction$object	_jc_javax_swing_text_TextAction$object;

typedef const struct _jc_javax_swing_text_TextAction$vmethods	_jc_javax_swing_text_TextAction$vmethods;
typedef const struct _jc_javax_swing_text_TextAction$vtable	_jc_javax_swing_text_TextAction$vtable;
typedef const struct _jc_javax_swing_text_TextAction$vtype	_jc_javax_swing_text_TextAction$vtype;

// Constructors
extern void _jc_javax_swing_text_TextAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_TextAction$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_javax_swing_text_JTextComponent$object *_jc_javax_swing_text_TextAction$method$getFocusedComponent$c5860e804e4a3d79(_jc_env *, struct _jc_javax_swing_text_TextAction$object *);
extern struct _jc_javax_swing_text_JTextComponent$object *_jc_javax_swing_text_TextAction$method$getTextComponent$66041b8eed9edaf9(_jc_env *, struct _jc_javax_swing_text_TextAction$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_TextAction$method_info$getFocusedComponent$c5860e804e4a3d79;
extern _jc_method _jc_javax_swing_text_TextAction$method_info$getTextComponent$66041b8eed9edaf9;

// Static methods
extern _jc_object_array *_jc_javax_swing_text_TextAction$method$augmentList$64848e4748e65223(_jc_env *, struct _jc_object_array *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_javax_swing_text_TextAction$vmethods {
	struct _jc_javax_swing_text_JTextComponent$object	*(*getFocusedComponent$c5860e804e4a3d79)(_jc_env *, struct _jc_javax_swing_text_TextAction$object *);
	struct _jc_javax_swing_text_JTextComponent$object	*(*getTextComponent$66041b8eed9edaf9)(_jc_env *, struct _jc_javax_swing_text_TextAction$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_TextAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
};

// Vtype
struct _jc_javax_swing_text_TextAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_TextAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_TextAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_TextAction$refs {
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_TextAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_TextAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
};

// Object instance structure
struct _jc_javax_swing_text_TextAction$object {
	_jc_javax_swing_text_TextAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_TextAction$vtype	*vtype;
	_jc_javax_swing_text_TextAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_TextAction$vtype _jc_javax_swing_text_TextAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_TextAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_TextAction$class_object;

#endif	/* _JC_javax_swing_text_TextAction_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/TextAction.h <==
// public abstract class javax.swing.text.TextAction

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f02353a2de7b0e85 javax_swing_AbstractAction
// @dep_class ebc1c295cb90fd47 javax_swing_text_TextAction

// header file dependencies
// @dep_header javax_swing_AbstractAction

#include "javax/swing/AbstractAction.h"

#ifndef _JC_javax_swing_text_TextAction_H_
#define _JC_javax_swing_text_TextAction_H_

// Forward structure declarations
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_JTextComponent$object;

// Typedefs
typedef struct _jc_javax_swing_text_TextAction$sub_refs	_jc_javax_swing_text_TextAction$sub_refs;
typedef struct _jc_javax_swing_text_TextAction$sub_nonrefs	_jc_javax_swing_text_TextAction$sub_nonrefs;
typedef struct _jc_javax_swing_text_TextAction$refs	_jc_javax_swing_text_TextAction$refs;
typedef struct _jc_javax_swing_text_TextAction$nonrefs	_jc_javax_swing_text_TextAction$nonrefs;
typedef struct _jc_javax_swing_text_TextAction$object	_jc_javax_swing_text_TextAction$object;

typedef const struct _jc_javax_swing_text_TextAction$vmethods	_jc_javax_swing_text_TextAction$vmethods;
typedef const struct _jc_javax_swing_text_TextAction$vtable	_jc_javax_swing_text_TextAction$vtable;
typedef const struct _jc_javax_swing_text_TextAction$vtype	_jc_javax_swing_text_TextAction$vtype;

// Constructors
extern void _jc_javax_swing_text_TextAction$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_swing_text_TextAction$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_text_JTextComponent$object *_jc_javax_swing_text_TextAction$method$getFocusedComponent$c5860e804e4a3d79(_jc_env *, struct _jc_javax_swing_text_TextAction$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_text_JTextComponent$object *_jc_javax_swing_text_TextAction$method$getTextComponent$66041b8eed9edaf9(_jc_env *, struct _jc_javax_swing_text_TextAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_TextAction$method_info$getFocusedComponent$c5860e804e4a3d79;
extern _jc_method _jc_javax_swing_text_TextAction$method_info$getTextComponent$66041b8eed9edaf9;

// Static methods
extern _jc_object_array *_jc_javax_swing_text_TextAction$method$augmentList$64848e4748e65223(_jc_env *, struct _jc_object_array *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_text_TextAction$vmethods {
	struct _jc_javax_swing_text_JTextComponent$object	*(*getFocusedComponent$c5860e804e4a3d79)(_jc_env *, struct _jc_javax_swing_text_TextAction$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_text_JTextComponent$object	*(*getTextComponent$66041b8eed9edaf9)(_jc_env *, struct _jc_javax_swing_text_TextAction$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_TextAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_AbstractAction$vmethods	javax_swing_AbstractAction;
	_jc_javax_swing_text_TextAction$vmethods	javax_swing_text_TextAction;
};

// Vtype
struct _jc_javax_swing_text_TextAction$vtype {
	_jc_type			type;
	_jc_javax_swing_text_TextAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_TextAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_text_TextAction$refs {
    _jc_javax_swing_text_TextAction$sub_refs	javax_swing_text_TextAction;
    _jc_javax_swing_AbstractAction$sub_refs	javax_swing_AbstractAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_TextAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_TextAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_AbstractAction$sub_nonrefs	javax_swing_AbstractAction;
    _jc_javax_swing_text_TextAction$sub_nonrefs	javax_swing_text_TextAction;
};

// Object instance structure
struct _jc_javax_swing_text_TextAction$object {
	_jc_javax_swing_text_TextAction$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_TextAction$vtype	*vtype;
	_jc_javax_swing_text_TextAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_TextAction$vtype _jc_javax_swing_text_TextAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_TextAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_TextAction$class_object;

#endif	/* _JC_javax_swing_text_TextAction_H_ */
